@@ -76,7 +76,14 @@ namespace interop_test
             var s1 = simpleService.ReturnString();
             var s2 = simpleService.ReturnString();
 
-
+            var sliceMut = simpleService.ReturnSliceMut();
+            sliceMut[0] = 44;
+            
+            var slice = simpleService.ReturnSlice();
+            Assert.Equal(slice.Count, 123);
+            Assert.Equal((int) slice[0], 44);
+            Assert.Equal((int) slice[1], 123);
+            
             uint value = 123;
             var lt = SimpleServiceLifetime.NewWith(ref value);
             var s3 = lt.ReturnStringAcceptSlice(System.Array.Empty<byte>());
